@@ -30,24 +30,24 @@ namespace Rstats {
       return SvPV_nolen(sv);
     }
 
-    SV* new_scalar(I32 iv) {
-      return sv_2mortal(newSViv(iv));
-    }
-
-    SV* new_scalar(U32 uv) {
-      return sv_2mortal(newSVuv(uv));
-    }
-    
     SV* new_scalar(SV* sv) {
       return sv_2mortal(newSVsv(sv));
     }
+
+    SV* new_scalar(const char* pv) {
+      return sv_2mortal(newSVpvn(pv, strlen(pv)));
+    }
     
-    SV* new_scalar(double nv) {
-      return sv_2mortal(newSVnv(nv));
+    SV* new_scalar_iv(I32 iv) {
+      return sv_2mortal(newSViv(iv));
     }
 
-    SV* new_scalar(char* pv) {
-      return sv_2mortal(newSVpvn(pv, strlen(pv)));
+    SV* new_scalar_uv(U32 uv) {
+      return sv_2mortal(newSVuv(uv));
+    }
+    
+    SV* new_scalar_nv(double nv) {
+      return sv_2mortal(newSVnv(nv));
     }
     
     AV* new_array() {
@@ -107,10 +107,6 @@ namespace Rstats {
       
       return element;
     }
-
-    SV* array_fetch(AV* av, SV* pos_sv) {
-      return array_fetch(av, get_iv(pos_sv));
-    }
     
     SV* array_fetch(SV* av_ref, I32 pos) {
       AV* av = array_deref(av_ref);
@@ -120,10 +116,6 @@ namespace Rstats {
       return element;
     }
 
-    SV* array_fetch(SV* av_ref, SV* pos_sv) {
-      return array_fetch(av_ref, get_iv(pos_sv));
-    }
-
     HV* hash_deref(SV* ref) {
       if (SvROK(ref)) {
         return (HV*)SvRV(ref);
@@ -133,7 +125,7 @@ namespace Rstats {
       }
     }
     
-    SV* hash_fetch(HV* hv, char* key) {
+    SV* hash_fetch(HV* hv, const char* key) {
       SV** const element_ptr = hv_fetch(hv, key, strlen(key), FALSE);
       SV* const element = element_ptr ? *element_ptr : &PL_sv_undef;
       
@@ -144,7 +136,7 @@ namespace Rstats {
       return hash_fetch(hv, get_pv(key_sv));
     }
     
-    SV* hash_fetch(SV* hv_ref, char* key) {
+    SV* hash_fetch(SV* hv_ref, const char* key) {
       HV* hv = hash_deref(hv_ref);
       SV** const element_ptr = hv_fetch(hv, key, strlen(key), FALSE);
       SV* const element = element_ptr ? *element_ptr : &PL_sv_undef;
@@ -175,11 +167,11 @@ namespace Rstats {
       return new_array_ref_sv;
     }
     
-    void hash_store(HV* hv, char* key, SV* element) {
+    void hash_store(HV* hv, const char* key, SV* element) {
       hv_store(hv, key, strlen(key), SvREFCNT_inc(element), FALSE);
     }
 
-    void hash_store(SV* hv_ref, char* key, SV* element) {
+    void hash_store(SV* hv_ref, const char* key, SV* element) {
       HV* hv = hash_deref(hv_ref);
       hv_store(hv, key, strlen(key), SvREFCNT_inc(element), FALSE);
     }
@@ -194,7 +186,7 @@ namespace Rstats {
 
     void array_unshift(AV* av, SV* sv) {
       av_unshift(av, 1);
-      array_store(av, 0, sv);
+      array_store(av, (I32)0, sv);
     }
     
     void array_unshift(SV* av_ref, SV* sv) {
@@ -210,9 +202,9 @@ namespace Rstats {
       return c_obj;
     }
 
-    template <class X> SV* to_perl_obj(X c_obj, char* class_name) {
+    template <class X> SV* to_perl_obj(X c_obj, const char* class_name) {
       I32 obj_addr = PTR2IV(c_obj);
-      SV* obj_addr_sv = new_scalar(obj_addr);
+      SV* obj_addr_sv = new_scalar_iv(obj_addr);
       SV* obj_addr_sv_ref = new_ref(obj_addr_sv);
       SV* perl_obj = sv_bless(obj_addr_sv_ref, gv_stashpv(class_name, 1));
       
@@ -366,7 +358,7 @@ namespace Rstats {
       return elements;
     }
     
-    static Rstats::Elements* new_integer(int iv) {
+    static Rstats::Elements* new_integer_iv(I32 iv) {
       
       Rstats::Elements* elements = new Rstats::Elements;
       elements->values = new Rstats::Values::Integer(1, iv);
@@ -383,7 +375,7 @@ namespace Rstats {
       return elements;
     }
     
-    static Rstats::Elements* new_logical(I32 iv) {
+    static Rstats::Elements* new_logical_iv(I32 iv) {
       Rstats::Elements* elements = new Rstats::Elements;
       elements->values = new Rstats::Values::Integer(1, iv);
       elements->type = Rstats::ElementsType::LOGICAL;
@@ -408,11 +400,11 @@ namespace Rstats {
     }
     
     static Rstats::Elements* new_true() {
-      return new_logical(1);
+      return new_logical_iv(1);
     }
 
     static Rstats::Elements* new_false() {
-      return new_logical(0);
+      return new_logical_iv(0);
     }
     
     static Rstats::Elements* new_NaN() {
@@ -431,7 +423,7 @@ namespace Rstats {
       Rstats::Elements* elements = new Rstats::Elements;
       elements->values = new Rstats::Values::Integer(1, 0);
       elements->type = Rstats::ElementsType::LOGICAL;
-      elements->add_na_position((I32)0);
+      elements->add_na_position(0);
       
       return elements;
     }
@@ -443,11 +435,11 @@ namespace Rstats {
     Rstats::Elements* is_infinite(Rstats::Elements* elements) {
       
       Rstats::Values::Integer* rets_values;
-      int size = elements->get_size();
+      I32 size = elements->get_size();
       if (elements->get_type() == Rstats::ElementsType::DOUBLE) {
         Rstats::Values::Double* values = elements->get_double_values();
         rets_values = new Rstats::Values::Integer(size);
-        for (int i = 0; i < size; i++) {
+        for (I32 i = 0; i < size; i++) {
           if(std::isinf((*values)[i])) {
             (*rets_values)[i] = 1;
           }
@@ -466,12 +458,12 @@ namespace Rstats {
     }
 
     Rstats::Elements* is_nan(Rstats::Elements* elements) {
-      int size = elements->get_size();
+      I32 size = elements->get_size();
       Rstats::Values::Integer* rets_values;
       if (elements->get_type() == Rstats::ElementsType::DOUBLE) {
         Rstats::Values::Double* values = elements->get_double_values();
         rets_values = new Rstats::Values::Integer(size);
-        for (int i = 0; i < size; i++) {
+        for (I32 i = 0; i < size; i++) {
           if(std::isnan((*values)[i])) {
             (*rets_values)[i] = 1;
           }
@@ -491,7 +483,7 @@ namespace Rstats {
 
     Rstats::Elements* is_finite(Rstats::Elements* elements) {
       
-      int size = elements->get_size();
+      I32 size = elements->get_size();
       Rstats::Values::Integer* rets_values;
       if (elements->get_type() == Rstats::ElementsType::INTEGER) {
         Rstats::Values::Integer* values = elements->get_integer_values();
@@ -502,7 +494,7 @@ namespace Rstats {
         Rstats::Values::Double* values = elements->get_double_values();
         
         rets_values = new Rstats::Values::Integer(size);
-        for (int i = 0; i < size; i++) {
+        for (I32 i = 0; i < size; i++) {
           if (std::isfinite((*values)[i])) {
             (*rets_values)[i] = 1;
           }
